!---------------------------------------------------------------------------------------
! PREP_SATELLITE: prep_ageclass
!---------------------------------------------------------------------------------------
!  FLEXINVERT is free software: you can redistribute it and/or modify
!  it under the terms of the GNU General Public License as published by
!  the Free Software Foundation, either version 3 of the License, or
!  (at your option) any later version.
!
!  FLEXINVERT is distributed in the hope that it will be useful,
!  but WITHOUT ANY WARRANTY; without even the implied warranty of
!  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!  GNU General Public License for more details.
!
!  You should have received a copy of the GNU General Public License
!  along with FLEXINVERT.  If not, see <http://www.gnu.org/licenses/>.
!
!  Copyright 2017, Rona Thompson
!---------------------------------------------------------------------------------------
!
!> prep_ageclass
!!
!! Purpose:    Prepares the options file AGECLASS.
!!
!! Interface:
!!
!!    Inputs
!!             settings  -  settings data structure
!!             jd        -  julian day of start of month
!!
!!    Externals
!!             caldate
!!
!---------------------------------------------------------------------------------------

subroutine prep_ageclass(settings, jd)

  use mod_var
  use mod_settings
  use mod_dates

  implicit none

  type (settings_t), intent(in) :: settings
  real(kind=8),      intent(in) :: jd

  character(len=max_path_len)   :: filename
  character(len=8)              :: adate
  integer                       :: jjjjmmdd, hhmiss
  integer                       :: ierr
  integer                       :: nageclass, lage

  namelist /ageclass/ &
    nageclass, &
    lage

  ! preset namelist variables
  nageclass = 1
  lage = settings%ageclass

  call caldate(jd, jjjjmmdd, hhmiss)
  write(adate,fmt='(I8.8)') jjjjmmdd
  filename = trim(settings%path_options)//adate//'/options/AGECLASSES'

  ! write namelist file format
  open(100,file=trim(filename),status='replace',action='write',iostat=ierr)
  write(100,nml=ageclass)
  close(100)

end subroutine prep_ageclass
