#!/bin/bash 
#---------------------------------------------------
# Run FLEXPART jobs for satellite observations
#---------------------------------------------------
# Guide to use:
#   1. edit the directories, exename, list of stations
#      months and year below
#   2. for slurm set SLURM = 1 otherwise uses nohup  
#   3. the meteorology used for flexpart can be 
#      specified by METEO
#   4. run the script:
#      ./run_flexpart.sh
#---------------------------------------------------

# User settings
SLURM=1
PRIORITY=normal
TIMELIM=2-00:00:00
PARTITION=nilu
EXENAME=FLEXPART
DIRFLEX=/mypath/FLEXPART_v104/
DIROPTIONS=/mypath/flexpart_input/
PREFIX=releases_s5p_ch4
YEAR=2020
MONLIST=07
DAYLIST=(01 02 03 04 05 06 07 08 09 10 11 12 13 14 15
         16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31)

#---------------------------------------------------

NDAY=${#DAYLIST[@]}
echo "number of days: "${NDAY}
ARRAYDAY=`seq 1 ${NDAY}`

NMON=${#MONLIST[@]}
echo "number of months: "${NMON}
ARRAYMON=`seq 1 ${NMON}`

# check FLEXPART executable

cd ${DIRFLEX}src/
if [ ! `ls ${DIRFLEX}src/${EXENAME}` ]; then
  make -j serial ncf=yes
  if [ ! `ls ${DIRFLEX}src/${EXENAME}` ]; then                               
    echo "cannot create exec: "${DIRFLEX}src/${EXENAME}
    exit -1
  fi
fi 
chmod u+x ${EXENAME}

# loop over FLEXPART runs

for k in ${ARRAYMON}
do
  j=`expr $k - 1`
  MON=${MONLIST[$j]}
  for i in ${ARRAYDAY} 
  do 
    l=`expr $i - 1`
    DAY=${DAYLIST[$l]}

    # check RELEASES NCDF file exists if not go to next iteration
    echo ${DIROPTIONS}${YEAR}${MON}${DAY}/options/${PREFIX}_${YEAR}${MON}${DAY}.nc
    if [ ! `ls ${DIROPTIONS}${YEAR}${MON}${DAY}/options/${PREFIX}_${YEAR}${MON}${DAY}.nc` ]; then 
      continue
    fi

    # set-up job
    cd ${DIROPTIONS}${YEAR}${MON}${DAY}
    rm -f job_${MON}${DAY}
    rm -f flex.log
    cp -f  ${DIRFLEX}src/${EXENAME} job_${MON}${DAY}
    OUTPUT=flex.log
    echo "submitting job for: "${YEAR}${MON}${DAY}

    if [ ${SLURM} -eq 1 ]; then
    # create submit.sh for submitting to slurm
cat <<EOF > submit.sh
#!/bin/bash
./job_${MON}${DAY}
EOF
#sbatch --job-name=job_${MON}${DAY} --qos=${PRIORITY} --partition=${PARTITION} --time=${TIMELIM} --mem-per-cpu=50000 --output=${OUTPUT} submit.sh
sbatch --job-name=job_${MON}${DAY} --partition=${PARTITION} --time=${TIMELIM} --mem-per-cpu=50000 --output=${OUTPUT} submit.sh
      sleep 2 
      rm -f submit.sh
    else
    # use nohup
      nohup ./job_${MON}${DAY} > ${OUTPUT} 
      sleep 2
    fi

  done
done

# the end


